.ocean-post-settings-container .content-help{line-height:1.5}.interface-interface-skeleton__sidebar .ocean-post-settings-container.help-container{padding-top:0}
.ocean-reset-page-settings .components-base-control__field{align-items:center;display:flex;flex-direction:row;justify-content:space-between}.ocean-component-option-reset__button{height:28px;position:relative;width:28px}.ocean-component-option-reset__button .components-circular-option-reset__button{display:inline-block;height:28px;position:relative;transform:scale(1);transition:transform .3s ease;vertical-align:top;width:28px;will-change:transform}.ocean-component-option-reset__button .components-circular-option-reset__button .components-circular-button-icon{border:none;border-radius:50%;box-shadow:none;cursor:pointer;display:inline-block;height:100%;min-width:10px;padding:0;transition:box-shadow .1s ease;transition:transform .3s ease;vertical-align:top;width:100%}.ocean-component-option-reset__button .components-circular-option-reset__button .components-circular-button-icon svg{color:var(--wp-admin-theme-color);margin:1px 0 0 1px}.ocean-component-option-reset__button .components-circular-option-reset__button .components-circular-button-icon:hover{transform:scale(1.2)}.ocean-reset--modal-container{margin:0 auto;text-align:center}.ocean-component-reset-button-group{display:block}.ocean-component-reset-button-group .ocean-component-button-group__buttons{align-items:center;display:flex;flex-direction:row;gap:20px;justify-content:center;margin-top:40px;width:100%}.ocean-component-reset-button-group .components-button{border:1px solid #e7e7e7;border-radius:5px!important;box-shadow:none;color:#5b5a5a;display:flex;font-weight:400;font-weight:500;height:45px;justify-content:center;outline:0;padding:5px;width:32%}.ocean-component-reset-button-group .components-button:not(:last-child){border-right:0}.ocean-component-reset-button-group .components-button.is-primary{background-color:#ff8039;box-shadow:none;color:#000}.ocean-component-reset-button-group .components-button.is-primary:focus:not(:disabled){box-shadow:none}.ocean-component-reset-button-group .components-button.is-primary:active:not(:disabled),.ocean-component-reset-button-group .components-button.is-primary:hover:not(:disabled){background-color:#ec3e05}.ocean-component-reset-button-group .components-button:focus:not(:disabled){box-shadow:none}.ocean-reset-modal .components-modal__header{border-bottom:1px solid #eae9e9;height:60px;padding:16px 32px}.ocean-reset-modal .reset-modal--content{line-height:1.6}@media(min-width:600px){.components-modal__frame.ocean-reset-modal{max-width:680px}.components-modal__frame.ocean-reset-modal .reset-modal--content{line-height:1.6;padding:0 1.5em}}
.ocean-upsell-area{padding-top:5px;text-align:center}.ocean-upsell-area .upsell-icon svg{height:34px;width:34px}.ocean-upsell-area .stacked-cta .cta-links:not(:last-child){margin-bottom:10px}.ocean-upsell-area .cta-links{border:1px solid #0284c7;border-radius:2px;color:#0284c7;display:block;padding:8px;text-decoration:none;width:100%}.ocean-upsell-area .cta-links:active,.ocean-upsell-area .cta-links:hover{border-color:#047bb7;color:#047bb7}.ocean-upsell-area .upsell-content{margin-bottom:15px;margin-top:15px}.ocean-post-settings .ocean-upsell-notice .components-panel__icon{margin:3px 10px 0 2px}.ocean-post-settings .ocean-upsell-notice .components-panel__icon svg{height:24px;width:24px}
:root{--hue-color:225;--first-color:hsl(var(--hue-color),48%,35%);--title-color:hsl(var(--hue-color),48%,22%);--text-color:hsl(var(--hue-color),12%,35%);--owp-accordian-small-font-size:.813rem;--owp-accordian-smaller-font-size:.75rem}@media screen and (min-width:968px){:root{--owp-accordian-small-font-size:.875rem;--owp-accordian-smaller-font-size:.813rem}}.ocean-accordion-component{align-content:center;display:grid}.ocean-accordion-component .accordion__container{display:grid;row-gap:.75rem}.ocean-accordion-component .accordion__title{color:var(--title-color);font-size:var(--small-font-size);font-weight:400;margin-bottom:0;margin-top:.15rem;text-transform:capitalize;transition:.2s}.ocean-accordion-component .accordion__header{-moz-column-gap:.5rem;column-gap:.5rem;cursor:pointer;display:flex;padding:.75rem}.ocean-accordion-component .accordion__description{font-size:var(--smaller-font-size);padding:.5rem .75rem 1rem}.ocean-accordion-component .accordion__icon{color:var(--title-color);font-size:1.5rem;height:-moz-max-content;height:max-content;transition:.3s}.ocean-accordion-component .accordion__item{background-color:#e4f5fc;border-radius:.25rem;box-shadow:0 2px 6px rgba(38,38,38,.1);position:relative;transition:all .25s ease}.ocean-accordion-component .accordion__item:after{background-color:#84d4ff;border-radius:.25rem 0 0 .25rem;content:"";height:100%;left:0;position:absolute;top:0;width:5px}.ocean-accordion-component .accordion__content{height:0;overflow:hidden;transition:height .3s ease}.accordion-open .accordion__icon{transform:rotate(45deg)}.accordion-open .accordion__title{font-weight:600}.accordion-open .accordion__content{height:auto}.accordion-open.accordion__item{background-color:#ebfffc}.accordion-open.accordion__item:after{background-color:#5ad882}
.ocean-image-picker .components-button-group{display:flex;justify-content:space-between;width:100%}.ocean-image-picker .components-button-group button{display:inline-block;text-align:center;width:45%}
.ocean-component-device-preview{display:flex;justify-content:flex-end;margin-bottom:-20px}.ocean-component-device-preview .ocean-device-preview{border-style:none;box-shadow:none!important;height:24px;padding:5px;width:24px}.ocean-component-device-preview .ocean-device-preview.active-tab{color:var(--wp-admin-theme-color)}.ocean-component-device-preview .ocean-device-preview .dashicon{font-size:15px;line-height:20px}.ocean-component-button-group.ocean-component-has-responsive .ocean-component-button-group__label{padding-bottom:0}.ocean-component-button-group.ocean-component-has-responsive .ocean-component-device-preview{display:flex;flex-direction:row}.ocean-component-button-group.ocean-component-has-responsive .ocean-component-device-preview .ocean-device-preview{border-style:none;box-shadow:none!important;height:24px;padding:5px;width:24px}
:root{--cssPosition:50%}.ocean-component-control-range-slider{width:100%}.ocean-range-slider-section{align-items:center;display:flex;justify-content:space-between;margin-bottom:20px}.ocean-range-slider-section .ocean-range-slider--slider{-webkit-margin-end:16px;border-radius:2px;cursor:pointer;height:18px;margin-inline-end:16px;position:relative;-webkit-user-select:none;-moz-user-select:none;user-select:none;width:calc(67% - 5px)}.ocean-range-slider-section .ocean-range-slider--slider .slider-input{box-sizing:border-box;cursor:pointer;display:block;height:100%;left:0;margin:0 -6px;opacity:0;outline:none;position:absolute;right:0;top:0;width:calc(100% + 12px)}.ocean-range-slider-section .ocean-range-slider--slider .ocean-range-slider-track{-webkit-margin-end:14px;border-radius:2px;cursor:pointer;height:18px;margin-inline-end:14px;position:relative;-webkit-user-select:none;-moz-user-select:none;user-select:none}.ocean-range-slider-section .ocean-range-slider--slider .ocean-range-slider-track:before{background:#cdd0d2;border-radius:inherit;content:"";height:2px;left:0;position:absolute;top:calc(50% - 1px);width:calc(100% + 14px)}.ocean-range-slider-section .ocean-range-slider--slider .ocean-range-slider-track div{background:var(--wp-components-color-accent,var(--wp-admin-theme-color,#007cba));border-radius:inherit;height:2px;left:0;padding-right:7px;position:absolute;top:calc(50% - 1px)}.ocean-range-slider-section .ocean-range-slider--slider .ocean-range-slider-track span{background:var(--wp-components-color-accent,var(--wp-admin-theme-color,#007cba));border-radius:100%;bottom:0;height:14px;left:var(--cssPosition);margin:auto 0;outline:none;position:absolute;top:0;transition:box-shadow .1s ease,background .1s ease;width:14px}.ocean-range-slider-section .ocean-range-slider--input{align-items:center;background:#fff;border:1px solid #cfcece;border-radius:3px;box-sizing:border-box;display:grid;grid-template-columns:repeat(2,1fr);height:30px;position:relative;transition:background .1s ease,border-color .1s ease;width:33%}.ocean-range-slider-section .ocean-range-slider--input input[type=number]{-moz-appearance:textfield;min-width:0;position:relative;text-align:center;z-index:1}.ocean-range-slider-section .ocean-range-slider--input input[type=number]::-webkit-inner-spin-button,.ocean-range-slider-section .ocean-range-slider--input input[type=number]::-webkit-outer-spin-button{-webkit-appearance:none;margin:0}.ocean-range-slider-section .ocean-range-slider--input input[type=number],.ocean-range-slider-section .ocean-range-slider--input input[type=text]{background-color:transparent;border:1px solid transparent!important;border-radius:3px!important;box-shadow:0 0 0 0 transparent;color:#555d66;font-size:11px!important;height:30px!important;line-height:normal;margin:-1px!important;min-height:auto;padding:5px!important;transition:box-shadow .1s linear,background .1s linear,border-radius .1s linear,border-color .1s linear;width:auto!important}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-value{align-items:center;color:#555d66;cursor:pointer;display:flex;flex-grow:1;font-size:10px;font-weight:600;height:100%;justify-content:center;letter-spacing:1px;line-height:normal;position:relative;text-transform:uppercase;transition:color .1s ease,font-weight .1s ease;-webkit-user-select:none;-moz-user-select:none;user-select:none}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-value:before{background:#ccc;content:"";height:50%;left:0;position:absolute;width:1px}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-list{grid-column-gap:5px;background:#fff;border:1px solid #ddd;border-radius:inherit;box-shadow:0 15px 15px rgba(0,0,0,.08);box-sizing:border-box;display:grid;grid-template-columns:repeat(2,minmax(0,1fr));left:-1px;opacity:0;padding:0 2px;position:absolute;top:-1px;transform:scale3d(.95,.95,1);transform-origin:center top;transition:opacity .1s ease,visibility .1s ease,transform .1s ease-out;visibility:hidden;width:calc(100% + 2px);z-index:2}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-list.show{opacity:1;transform:scaleX(1);visibility:visible}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-list:after{-webkit-margin-start:1px;-webkit-border-start:1px dashed #eee;align-self:center;border-inline-start:1px dashed #eee;content:"";height:calc(100% - 6px);justify-self:center;margin-inline-start:1px;position:absolute;width:1px}.ocean-range-slider-section .ocean-range-slider--input .ocean-range-slider-unit-list .unit-option{align-items:center;background:inherit;border-bottom:1px dashed #eee;color:#555d66;cursor:pointer;display:flex;font-size:9px;font-weight:700;height:26px;justify-content:center;letter-spacing:.06em;padding:2px 0;position:relative;text-transform:uppercase;z-index:1}
.ocean-component-typography__popover .components-popover__content{box-shadow:0 0 10px 4px #c7c7c7}.ocean-component__popover--content .react-select__control{cursor:pointer}.ocean-component__popover--content .react-select__value-container{position:static}.ocean-component__popover--content .react-select__value-container .react-select__single-value{align-items:center;display:flex;flex-direction:row;height:100%}.ocean-component__popover--content .react-select__value-container input.react-select__input{box-shadow:none}.ocean-component__popover--content.ocean-typograhpy--content .ocean-component-label,.ocean-typograhpy--content__font-family{margin-bottom:8px}.ocean-component-typograhpy--font-object{display:flex;flex-direction:row;flex-grow:1;justify-content:center}.ocean-component-typograhpy--font-object .ocean-font-object:nth-of-type(n+1){width:100%}.ocean-component-typograhpy--font-object .ocean-font-object:nth-of-type(2){padding-left:15px}.ocean-typograhpy--content__text-transform .ocean-editor-control-button.is-primary{z-index:0}.ocean-typo-popup-toolbar{align-items:center;border-bottom:1px solid #eaeaea;display:flex;justify-content:space-between;margin:-10px -10px 10px;padding:10px}.ocean-typo-popup-toolbar .components-button-group{align-items:center;display:flex;gap:10px}.ocean-typo-popup-toolbar .components-button-group .components-button{margin:0}.ocean-typo-popup-toolbar .reset-typo{align-items:center;box-shadow:none!important;display:flex;padding:0}.ocean-typo-popup-toolbar .ocean-component-device-preview{margin-bottom:0}.ocean-typo-popup-toolbar .ocean-component-device-preview .dashicon{font-size:18px}
.ocean-component-color-picker.ocean-has-popup .components-base-control__field{align-items:center;display:flex;justify-content:space-between;position:relative}.ocean-component-color-picker.ocean-has-popup .ocean-component-color-picker__container{height:28px;width:28px}.ocean-component-color-picker.ocean-has-popup .ocean-component-color-picker__container .components-color-palette__item{position:relative}.ocean-component-color-picker.ocean-has-inline .ocean-component-color-picker__container{margin-top:.5em}.ocean-component-color-picker.ocean-has-inline .components-circular-option-picker__option-wrapper{margin-right:0}.ocean-component-color-picker.ocean-has-inline .ocean-component-color-picker__inline{margin-top:1em}.ocean-component__popover--content .ocean-has-inline>.components-base-control__field{border-bottom:1px solid var(--color-border)}.ocean-component-color-picker--wrapper .components-color-picker,.ocean-component-color-picker--wrapper .components-color-picker .react-colorful{width:100%}.ocean-component-color-picker__palette{border-bottom:1px solid var(--color-border);margin-bottom:24px}.ocean-component-color-picker__palette .components-circular-option-picker .components-circular-option-picker__swatches{display:flex;flex-flow:row wrap;justify-content:space-between;margin-right:0}.ocean-component-color-picker__palette .components-circular-option-picker .components-circular-option-picker__swatches .components-circular-option-picker__option-wrapper{margin-right:0}.ocean-component-color-picker__header{align-items:center;display:flex;justify-content:space-between;position:relative}.ocean-component-color-picker__header .ocean-component-color-picker__header--button{height:28px;width:28px}.ocean-component-color-picker__popover .components-popover__content{padding:10px;width:300px}.ocean-component-color-picker__popover .components-color-picker__inputs-toggle{display:none}.ocean-component-color-picker__popover .components-color-picker__inputs-wrapper{min-width:auto}.ocean-color-picker__alpha{padding:0 16px 10px;position:relative}.ocean-color-picker__alpha--label{display:block;margin-bottom:8px}.ocean-color-picker__alpha--input{display:flex}.ocean-color-picker__alpha--input svg{cursor:pointer;height:30px;width:30px}.ocean-color-picker__alpha--input .components-range-control{flex-grow:1;padding-left:5px}
.ocean-media-url-picker .components-button-group{display:flex;justify-content:space-between;width:100%}.ocean-media-url-picker .components-button-group button{display:inline-block;text-align:center;width:45%}
.ocean-image-picker .components-button-group{display:flex;justify-content:space-between;width:100%}.ocean-image-picker .components-button-group button{display:inline-block;text-align:center;width:45%}
.ocean-document-settings{padding-top:5px;text-align:center}.ocean-document-settings .document-settings-icon{margin-bottom:1em}.ocean-document-settings .document-settings-icon svg{height:34px;width:34px}
:root{--color-border:#e7e7e7;--color-border-input:#c7c7c7}.ocean-svg{display:inline-block;vertical-align:middle}.ocean-svg svg{height:24px;width:24px}button.is-pressed.has-icon .ocean-svg svg path{color:#000}.components-dropdown-menu__menu .components-menu-items__item-icon svg{height:24px;width:24px}.ocean-post-settings{background-color:#ebe9eb}.ocean-post-settings .components-panel__body{background-color:#fff;border-bottom:0}.ocean-post-settings .components-panel__body.ocean-setting-panel>.components-panel__body-title{background-color:#fff}.ocean-post-settings .components-panel__body.ocean-setting-panel>.components-panel__body-title:hover{background-color:#ebe9eb}.ocean-post-settings .components-panel__body.ocean-setting-panel.is-addon+:not(.is-addon),.ocean-post-settings .components-panel__body.ocean-setting-panel:not(.is-addon)+.is-addon{margin-top:15px}.ocean-post-settings .components-panel__body.ocean-setting-panel.is-addon>.components-panel__body-title{background-color:#e4f5fc}.ocean-post-settings .components-panel__body.ocean-setting-panel.is-addon>.components-panel__body-title:hover{background-color:#ebfffc}.ocean-post-settings .components-panel__body-toggle.components-button{display:flex;flex-direction:row-reverse;justify-content:flex-end;padding:12px}.ocean-post-settings svg.components-panel__icon{height:24px;margin:0 10px 0 0;width:24px}.interface-interface-skeleton__sidebar .components-base-control{margin-bottom:20px}.interface-interface-skeleton__sidebar .components-base-control:last-child{margin-bottom:8px}.interface-interface-skeleton__sidebar .ocean-component-label,.interface-interface-skeleton__sidebar .ocean-control-label{display:inline-block;font-size:11px;font-weight:500;line-height:1.4;margin-bottom:8px;padding:0;text-transform:uppercase}.interface-interface-skeleton__sidebar .ocean-post-settings-container{padding-top:12px}.interface-interface-skeleton__sidebar .ocean-post-settings-container .components-base-control__label,.interface-interface-skeleton__sidebar .ocean-post-settings-container .components-input-control__label,.interface-interface-skeleton__sidebar .ocean-post-settings-container .ocean-component-label,.interface-interface-skeleton__sidebar .ocean-post-settings-container .ocean-component-label--text{font-size:13px!important;text-transform:capitalize!important}.interface-interface-skeleton__sidebar .control-help{color:#757575;font-size:12px;font-style:normal;margin-bottom:0;margin-top:0}.ocean-post-settings .ocean-component__base_control .components-base-control__field{align-items:center;display:flex;justify-content:space-between;position:relative}.ocean-component__container--options{display:flex;height:28px;width:100%}.ocean-component__container--options-refresh.components-button.has-text{box-shadow:none;height:28px;justify-content:right;min-width:24px;padding:0}.ocean-component__container--options-refresh.components-button.has-text svg{color:#919090;margin-right:0;width:17px}.ocean-component__container--options-refresh.components-button.has-text svg:hover{color:var(--wp-admin-theme-color)}.ocean-component__container--options .components-circular-option-picker__option-wrapper{margin-right:0}.ocean-component__container .components-color-palette__item{background:#fff;color:#fff;position:relative}.ocean-component__container .components-color-palette__item.has-icon{min-width:10px;padding:5px}.ocean-component__container .components-color-palette__item.has-icon .dashicon{color:#a9a9a9;font-size:16px;margin-left:0}.ocean-component__container .components-color-palette__item.has-icon svg{color:var(--wp-admin-theme-color);height:16px;margin:1px 0 0 1px;width:16px}.ocean-component__container .components-color-palette__item:hover,.ocean-component__container .components-color-palette__item[aria-expanded=true]{color:#fff}.ocean-component__container .components-color-palette__item:focus{background-color:#fff}.ocean-component__popover .components-popover__content{padding:10px;width:300px}.ocean-component__popover .components-popover__content .components-base-control__label,.ocean-component__popover .components-popover__content .components-input-control__label,.ocean-component__popover .components-popover__content .ocean-component-label,.ocean-component__popover .components-popover__content .ocean-component-label--text{font-size:13px!important;font-weight:500;text-transform:capitalize!important}.ocean-component__container--header{margin-bottom:5px}.ocean-component-has-unit--flex,.ocean-component__container--header{align-items:center;display:flex;justify-content:space-between}.ocean-component-has-unit--flex .ocean-component-has-unit-picker{width:100%}.ocean-component-has-unit--flex .ocean-component-has-unit-picker .components-input-control__backdrop{border-color:var(--color-border-input);border-radius:0}.ocean-component-unit-picker{border:1px solid var(--color-border-input);height:30px;margin-left:-1px}.ocean-component-button-group{display:block}.ocean-component-button-group .ocean-component-button-group__buttons{align-items:center;display:flex;flex-direction:row;margin-bottom:24px;width:100%}.ocean-component-button-group .ocean-component-button-group__label{display:block;padding-bottom:10px;width:100%}.ocean-component-button-group .components-button{border:1px solid var(--color-border);box-shadow:none;color:#5b5a5a;display:flex;flex:1 1 auto;font-size:12px;font-weight:400;font-weight:500;height:35px;justify-content:center;outline:0;padding:5px}.ocean-component-button-group .components-button:not(:last-child){border-right:0}.ocean-component-button-group .components-button.is-primary{box-shadow:none;color:#fff}.ocean-component-button-group .components-button.is-primary:focus:not(:disabled),.ocean-component-button-group .components-button:focus:not(:disabled){box-shadow:none}.ocean-component-unit-alignment .ocean-component-has-unit--flex{align-items:center;display:flex;justify-content:space-between}.ocean-component-unit-alignment .ocean-component-has-unit--flex .ocean-component-has-unit-picker{width:100%}.ocean-component-unit-alignment .ocean-component-has-unit--flex .ocean-component-has-unit-picker .components-input-control__backdrop{border-color:var(--color-border-input);border-radius:0}.ocean-component-unit-alignment .ocean-unit-picker{border:1px solid var(--color-border-input);height:30px;margin-left:-1px;margin-top:18.5px}.ocean-post-settings-container .settings-help-link{align-items:center;color:#5e5c5c;display:flex;font-size:12px;gap:5px;margin-top:1.8rem}.ocean-post-settings-container .settings-help-link a:not(:hover){text-decoration:none}.ocean-component-settings__reset{align-items:center;background:#f1f1f1;border-radius:3px;display:flex;justify-content:space-between;padding:0 10px}.ocean-component-settings__reset .components-circular-option-reset__button .components-button{box-shadow:none;padding:0}
